@@ -1,20 +1,25 @@
 
-/***************************************************************************
-                          breakpoint_cmds.c  - breakpoint commands for xsldbg
-                             -------------------
-    begin                : Wed Nov 21 2001
-    copyright            : (C) 2001 by Keith Isdale
-    email                : k_isdale@tpg.com.au
- ***************************************************************************/
+/**
+ *
+ *  This file is part of the kdewebdev package
+ *  Copyright (c) 2001 Keith Isdale <keith@kdewebdev.org>
+ *
+ *  This library is free software; you can redistribute it and/or 
+ *  modify it under the terms of the GNU General Public License as 
+ *  published by the Free Software Foundation; either version 2 of 
+ *  the License, or (at your option) any later version.
+ *
+ *  This library is distributed in the hope that it will be useful,
+ *  but WITHOUT ANY WARRANTY; without even the implied warranty of
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ *  Library General Public License for more details.
+ *
+ *  You should have received a copy of the GNU Library General Public License
+ *  along with this library; see the file COPYING.LIB.  If not, write to
+ *  the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+ *  Boston, MA 02110-1301, USA.
+ **/
 
-/***************************************************************************
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- ***************************************************************************/
 
 #include "xsldbg.h"
 #include "debugXSL.h"
@@ -22,7 +27,6 @@
 #include "utils.h"
 #include <libxml/valid.h>       /* needed for xmlSplitQName2 */
 #include <libxml/xpathInternals.h> /* needed for xmlNSLookup */
-#include <libxml/uri.h>    /* needed for  xmlURIEscapeStr */
 #include "xsldbgthread.h"       /* for getThreadStatus() */
 #include "xsldbgmsg.h"
 #include "options.h"
@@ -40,24 +44,8 @@ const xmlChar *orphanedTemplateURL= (xmlChar*)"http://xsldbg.sourceforge.net/def
    Private function declarations for breakpoint_cmds.c
  ----------------------------------------------------*/
 
-/**
- * validateSource:
- * @url : is valid name of a xsl source file
- * @lineNo : lineNo >= 0
- *
- * Returns 1 if a breakpoint could be set at specified file url and line number
- *         0 otherwise
- */
 int validateSource(xmlChar ** url, long *lineNo);
 
-/**
- * validateData:
- * @url : is valid name of a xml data file
- * @lineNo : lineNo >= 0
- *
- * Returns 1 if a breakpoint could be set at specified file url and line number
- *         0 otherwise
- */
 int validateData(xmlChar ** url, long *lineNo);
 
 
@@ -74,18 +62,7 @@ int validateData(xmlChar ** url, long *lineNo);
   ------------------------------------------- */
 
 
-/**
- * xslDbgShellFrameBreak:
- * @arg: Is valid number of frames to change location by
- * @stepup: If != 1 then we step up, otherwise step down
- *
- * Set a "frame" break point either up or down from here
- *
- * Returns 1 on success,
- *         0 otherwise
- */
-int
-xslDbgShellFrameBreak(xmlChar * arg, int stepup)
+int xslDbgShellFrameBreak(xmlChar * arg, int stepup)
 {
     int result = 0;
 
@@ -110,7 +87,7 @@ xslDbgShellFrameBreak(xmlChar * arg, int stepup)
 
     if (xmlStrLen(arg) > 0) {
         if (!sscanf((char *) arg, "%d", &noOfFrames)) {
-            xsldbgGenericErrorFunc(i18n("Error: Unable to parse %1 as a number of frames.\n").arg((char*)arg));
+            xsldbgGenericErrorFunc(i18n("Error: Unable to parse %1 as a number of frames.\n", (char*)arg));
 	    noOfFrames = -1;
         }
     } else {
@@ -131,16 +108,7 @@ xslDbgShellFrameBreak(xmlChar * arg, int stepup)
 }
 
 
-/**
- * validateSource:
- * @url : is valid name of a xsl source file
- * @lineNo : lineNo >= 0
- *
- * Returns 1 if a breakpoint could be set at specified file url and line number
- *         0 otherwise
- */
-int
-validateSource(xmlChar ** url, long *lineNo)
+int validateSource(xmlChar ** url, long *lineNo)
 {
 
     int result = 0, type;
@@ -188,7 +156,7 @@ validateSource(xmlChar ** url, long *lineNo)
                     walkChildNodes((xmlHashScanner) scanForNode, searchInf,
                                    searchData->node);
                     if (!searchInf->found) {
-                        xsldbgGenericErrorFunc(i18n("Warning: Breakpoint for file \"%1\" at line %2 does not seem to be valid.\n").arg(xsldbgUrl(*url)).arg(*lineNo));
+                        xsldbgGenericErrorFunc(i18n("Warning: Breakpoint for file \"%1\" at line %2 does not seem to be valid.\n", xsldbgUrl(*url), *lineNo));
                     }
 
                     *lineNo = searchData->lineNo;
@@ -210,9 +178,9 @@ validateSource(xmlChar ** url, long *lineNo)
                 result = 1;
             }
         } else{
-            xsldbgGenericErrorFunc(i18n("Error: Unable to find a stylesheet file whose name contains %1.\n").arg(xsldbgUrl(*url)));
+            xsldbgGenericErrorFunc(i18n("Error: Unable to find a stylesheet file whose name contains %1.\n", xsldbgUrl(*url)));
 	    if (lineNo){
-	      xsldbgGenericErrorFunc(i18n("Warning: Breakpoint for file \"%1\" at line %2 does not seem to be valid.\n").arg(xsldbgUrl(*url)).arg(*lineNo));
+	      xsldbgGenericErrorFunc(i18n("Warning: Breakpoint for file \"%1\" at line %2 does not seem to be valid.\n", xsldbgUrl(*url), *lineNo));
 	    }
 	}
     }
@@ -228,16 +196,7 @@ validateSource(xmlChar ** url, long *lineNo)
 
 
 
-/**
- * validateData:
- * @url : is valid name of a xml data file
- * @lineNo : lineNo >= 0
- *
- * Returns 1 if a breakpoint could be set at specified file url and line number
- *         0 otherwise
- */
-int
-validateData(xmlChar ** url, long *lineNo)
+int validateData(xmlChar ** url, long *lineNo)
 {
     int result = 0;
     searchInfoPtr searchInf;
@@ -299,9 +258,9 @@ validateData(xmlChar ** url, long *lineNo)
 
         if (!searchInf->found) {
 	  if (lineNo){
-             xsldbgGenericErrorFunc(i18n("Warning: Breakpoint for file \"%1\" at line %2 does not seem to be valid.\n").arg(xsldbgUrl(*url)).arg(*lineNo));
+             xsldbgGenericErrorFunc(i18n("Warning: Breakpoint for file \"%1\" at line %2 does not seem to be valid.\n", xsldbgUrl(*url), *lineNo));
 	  } else{
-             xsldbgGenericErrorFunc(i18n("Error: Unable to find a data file whose name contains %1.\n").arg(xsldbgUrl(*url)));
+             xsldbgGenericErrorFunc(i18n("Error: Unable to find a data file whose name contains %1.\n", xsldbgUrl(*url)));
 	  }
             result = 1;
         } else {
@@ -321,19 +280,7 @@ validateData(xmlChar ** url, long *lineNo)
 }
 
 
-/**
- * xslDbgShellBreak:
- * @arg: Is valid and in UTF-8
- * @style: Is valid
- * @ctxt: Is valid
- * 
- * Add break point specified by arg
- *
- * Returns 1 on success,
- *         0 otherwise
- */
-int
-xslDbgShellBreak(xmlChar * arg, xsltStylesheetPtr style,
+int xslDbgShellBreak(xmlChar * arg, xsltStylesheetPtr style,
                  xsltTransformContextPtr ctxt)
 {
     int result = 0;
@@ -372,23 +319,15 @@ xslDbgShellBreak(xmlChar * arg, xsltStylesheetPtr style,
             if (splitString(&arg[2], 2, opts) == 2) {
                 if ((xmlStrlen(opts[1]) == 0) || 
 		       !sscanf((char *) opts[1], "%ld", &lineNo)) {
-                    xsldbgGenericErrorFunc(i18n("Error: Unable to parse %1 as a line number.\n").arg((char*)opts[1]));
+                    xsldbgGenericErrorFunc(i18n("Error: Unable to parse %1 as a line number.\n", (char*)opts[1]));
 		    xsldbgGenericErrorFunc(QString("Error: %1\n").arg(i18n(errorPrompt)));
                     return result;
                 } else {
                     /* try to guess whether we are looking for source or data 
                      * break point
                      */
-                    xmlChar *escapedURI;
                     trimString(opts[0]);
-                    url = filesExpandName(opts[0]);
-                    if (url){
-                        escapedURI = xmlURIEscapeStr(url, (const xmlChar*)"/");
-                        if (escapedURI){
-                            xmlFree(url);
-                            url = escapedURI;
-                        }
-                    }
+                    url = xmlStrdup((const xmlChar*)filesExpandName(xsldbgText(opts[0])).toUtf8().constData());
                     if (url) {
 			if (!orphanedBreakPoint){
 			    if (filesIsSourceFile(url)) {
@@ -422,7 +361,7 @@ xslDbgShellBreak(xmlChar * arg, xsltStylesheetPtr style,
 		    }
                 }
             } else
-                xsldbgGenericErrorFunc(i18n("Error: Invalid arguments to command %1.\n").arg("break"));
+                xsldbgGenericErrorFunc(i18n("Error: Invalid arguments to command %1.\n", QString("break")));
         }
     } else {
         /* add breakpoint at specified template names */
@@ -524,7 +463,7 @@ xslDbgShellBreak(xmlChar * arg, xsltStylesheetPtr style,
 	  break;
 
 	default:	  
-	  xsldbgGenericErrorFunc(i18n("Error: Invalid arguments for command %1.\n").arg("break"));
+	  xsldbgGenericErrorFunc(i18n("Error: Invalid arguments for command %1.\n", QString("break")));
 	  return 0;
 	}
 
@@ -593,14 +532,14 @@ xslDbgShellBreak(xmlChar * arg, xsltStylesheetPtr style,
 					searchPtr->id = lastId;
 					result = 1;
 					breakPointCounter = lastCounter;
-					xsldbgGenericErrorFunc(i18n("Information: Breakpoint validation has caused breakpoint %1 to be re-created.\n").arg(searchPtr->id));
+					xsldbgGenericErrorFunc(i18n("Information: Breakpoint validation has caused breakpoint %1 to be re-created.\n", searchPtr->id));
 					validatedBreakPoints++;
 				    }
 				}
 			    }
 			}else{
 			    if (xsldbgValidateBreakpoints != BREAKPOINTS_BEING_VALIDATED){
-				xsldbgGenericErrorFunc(i18n("Warning: Breakpoint exits for file \"%1\" at line %2.\n").arg(xsldbgUrl(tempUrl)).arg(templateLineNo));
+				xsldbgGenericErrorFunc(i18n("Warning: Breakpoint exits for file \"%1\" at line %2.\n", xsldbgUrl(tempUrl), templateLineNo));
 			    }
 			    validatedBreakPoints++;
 			}
@@ -628,7 +567,7 @@ xslDbgShellBreak(xmlChar * arg, xsltStylesheetPtr style,
         } else {
             result = 1;
 	    if (newBreakPoints){
-		xsldbgGenericErrorFunc(i18n("Information: Added %n new breakpoint.", "Information: Added %n new breakpoints.", newBreakPoints) + QString("\n"));
+		xsldbgGenericErrorFunc(i18np("Information: Added %1 new breakpoint.", "Information: Added %1 new breakpoints.", newBreakPoints) + QString("\n"));
 	    }
         }
 
@@ -648,7 +587,7 @@ xslDbgShellBreak(xmlChar * arg, xsltStylesheetPtr style,
 
     if (!result) {
         if (url)
-            xsldbgGenericErrorFunc(i18n("Error: Failed to add breakpoint for file \"%1\" at line %2.\n").arg(xsldbgUrl(url)).arg(lineNo));
+            xsldbgGenericErrorFunc(i18n("Error: Failed to add breakpoint for file \"%1\" at line %2.\n", xsldbgUrl(url), lineNo));
         else
             xsldbgGenericErrorFunc(i18n("Error: Failed to add breakpoint.\n"));
     }
@@ -659,17 +598,7 @@ xslDbgShellBreak(xmlChar * arg, xsltStylesheetPtr style,
 }
 
 
-/**
- * xslDbgShellDelete:
- * @arg: Is valid and in UTF-8
- * 
- * Delete break point specified by arg
- *
- * Returns 1 on success,
- *         0 otherwise
- */
-int
-xslDbgShellDelete(xmlChar * arg)
+int xslDbgShellDelete(xmlChar * arg)
 {
     int result = 0, breakPointId;
     long lineNo;
@@ -692,18 +621,10 @@ xslDbgShellDelete(xmlChar * arg)
             if (splitString(&arg[2], 2, opts) == 2) {
                 if ((xmlStrlen(opts[1]) == 0) ||
 		    !sscanf((char *) opts[1], "%ld", &lineNo)) {
-                    xsldbgGenericErrorFunc(i18n("Error: Unable to parse %1 as a line number.\n").arg((char*)opts[1]));
+                    xsldbgGenericErrorFunc(i18n("Error: Unable to parse %1 as a line number.\n", (char*)opts[1]));
                 } else {
-                    xmlChar *escapedURI;
                     trimString(opts[0]);
-                    url = filesExpandName(opts[0]);
-                    if (url){
-                        escapedURI = xmlURIEscapeStr(url, (const xmlChar*)"/");
-                        if (escapedURI){
-                            xmlFree(url);
-                            url = escapedURI;
-                        }
-                    }
+                    url = xmlStrdup((const xmlChar*)filesExpandName(xsldbgText(opts[0])).toUtf8().constData());
                     if (url) {
                         if (filesIsSourceFile(url)) {
                             if (validateSource(&url, &lineNo))
@@ -711,7 +632,7 @@ xslDbgShellDelete(xmlChar * arg)
                         } else if (validateData(&url, &lineNo))
                             breakPtr = breakPointGet(url, lineNo);
                         if (!breakPtr || !breakPointDelete(breakPtr)){
-                            xsldbgGenericErrorFunc(i18n("Error: Breakpoint does not exist for file \"%1\" at line %2.\n").arg(xsldbgUrl(url)).arg(lineNo));
+                            xsldbgGenericErrorFunc(i18n("Error: Breakpoint does not exist for file \"%1\" at line %2.\n", xsldbgUrl(url), lineNo));
                         }else{
                             result = 1;
 			}
@@ -719,7 +640,7 @@ xslDbgShellDelete(xmlChar * arg)
                     }
                 }
             } else{
-		xsldbgGenericErrorFunc(i18n("Error: Invalid arguments for command %1.\n").arg("delete"));
+		xsldbgGenericErrorFunc(i18n("Error: Invalid arguments for command %1.\n", QString("delete")));
 	    }
         }
     } else if (xmlStrEqual((xmlChar*)"*", arg)) {
@@ -732,20 +653,20 @@ xslDbgShellDelete(xmlChar * arg)
         if (breakPtr) {
             result = breakPointDelete(breakPtr);
             if (!result) {
-                xsldbgGenericErrorFunc(i18n("Error: Unable to delete breakpoint %1.\n").arg(breakPointId));
+                xsldbgGenericErrorFunc(i18n("Error: Unable to delete breakpoint %1.\n", breakPointId));
             }
         } else {
-            xsldbgGenericErrorFunc(i18n("Error: Breakpoint %1 does not exist.\n").arg(breakPointId));
+            xsldbgGenericErrorFunc(i18n("Error: Breakpoint %1 does not exist.\n", breakPointId));
         }
     } else {
         breakPtr = findBreakPointByName(arg);
         if (breakPtr) {
             result = breakPointDelete(breakPtr);
             if (!result) {
-                xsldbgGenericErrorFunc(i18n("Error: Unable to delete breakpoint at template %1.\n").arg(xsldbgText(arg)));
+                xsldbgGenericErrorFunc(i18n("Error: Unable to delete breakpoint at template %1.\n", xsldbgText(arg)));
             }
         } else{
-            xsldbgGenericErrorFunc(i18n("Error: Breakpoint at template \"%1\" does not exist.\n").arg(xsldbgText(arg)));
+            xsldbgGenericErrorFunc(i18n("Error: Breakpoint at template \"%1\" does not exist.\n", xsldbgText(arg)));
 	}
     }
     if (!result) 
@@ -754,20 +675,7 @@ xslDbgShellDelete(xmlChar * arg)
 }
 
 
-/**
- * xslDbgShellEnableBreakPoint:
- * @payload: A valid breakPointPtr
- * @data: Enable type, a pointer to an integer 
- *         for a value of 
- *                 1 enable break point
- *                 0 disable break point
- *                 -1 toggle enabling of break point 
- * @name: Not used
- *
- * Enable/disable break points via use of scan of break points
-*/
-void
-xslDbgShellEnableBreakPoint(void *payload, void *data,
+void xslDbgShellEnableBreakPoint(void *payload, void *data,
                             xmlChar * name)
 {
     Q_UNUSED(name);
@@ -777,19 +685,8 @@ xslDbgShellEnableBreakPoint(void *payload, void *data,
 }
 
 
-/**
- * xslDbgShellEnable:
- * @arg : is valid and in UTF-8
- * @enableType : enable break point if 1, disable if 0, toggle if -1
- *
- * Enable/disable break point specified by arg using enable 
- *      type of @enableType
- * Returns 1 if successful,
- *         0 otherwise
- */
 
-int
-xslDbgShellEnable(xmlChar * arg, int enableType)
+int xslDbgShellEnable(xmlChar * arg, int enableType)
 {
     int result = 0, breakPointId;
     long lineNo;
@@ -818,18 +715,10 @@ xslDbgShellEnable(xmlChar * arg, int enableType)
             if (splitString(&arg[2], 2, opts) == 2) {
                 if ((xmlStrlen(opts[1]) == 0) ||
 		    !sscanf((char *) opts[1], "%ld", &lineNo)) {
-                    xsldbgGenericErrorFunc(i18n("Error: Unable to parse %1 as a line number.\n").arg((char*)opts[1]));
+                    xsldbgGenericErrorFunc(i18n("Error: Unable to parse %1 as a line number.\n", (char*)opts[1]));
                 } else {
-                    xmlChar *escapedURI;
                     trimString(opts[0]);
-                    url = filesExpandName(opts[0]);
-                    if (url){
-                        escapedURI = xmlURIEscapeStr(url, (const xmlChar*)"/");
-                        if (escapedURI){
-                            xmlFree(url);
-                            url = escapedURI;
-                        }
-                    }
+                    url = xmlStrdup((const xmlChar *)filesExpandName(xsldbgText(opts[0])).toUtf8().constData());
                     if (url) {
                         if (strstr((char *) url, ".xsl")) {
                             if (validateSource(&url, NULL))
@@ -839,13 +728,13 @@ xslDbgShellEnable(xmlChar * arg, int enableType)
                         if (breakPtr){
                             result = breakPointEnable(breakPtr, enableType);
                         }else{
-                            xsldbgGenericErrorFunc(i18n("Error: Breakpoint does not exist for file \"%1\" at line %2.\n").arg(xsldbgUrl(url)).arg(lineNo));
+                            xsldbgGenericErrorFunc(i18n("Error: Breakpoint does not exist for file \"%1\" at line %2.\n", xsldbgUrl(url), lineNo));
 			}
                         xmlFree(url);
                     }
                 }
             } else
-                xsldbgGenericErrorFunc(i18n("Error: Invalid arguments for command %1.\n").arg("enable"));
+                xsldbgGenericErrorFunc(i18n("Error: Invalid arguments for command %1.\n", QString("enable")));
         }
     } else if (xmlStrEqual((xmlChar*)"*", arg)) {
         result = 1;
@@ -858,17 +747,17 @@ xslDbgShellEnable(xmlChar * arg, int enableType)
         if (breakPtr) {
             result = breakPointEnable(breakPtr, enableType);
             if (!result) {
-                xsldbgGenericErrorFunc(i18n("Error: Unable to enable/disable breakpoint %1.\n").arg(breakPointId));
+                xsldbgGenericErrorFunc(i18n("Error: Unable to enable/disable breakpoint %1.\n", breakPointId));
             }
         } else {
-            xsldbgGenericErrorFunc(i18n("Error: Breakpoint %1 does not exist.\n").arg(breakPointId));
+            xsldbgGenericErrorFunc(i18n("Error: Breakpoint %1 does not exist.\n", breakPointId));
         }
     } else {
         breakPtr = findBreakPointByName(arg);
         if (breakPtr) {
             result = breakPointEnable(breakPtr, enableType);
         } else
-            xsldbgGenericErrorFunc(i18n("Error: Breakpoint at template \"%1\" does not exist.\n").arg(xsldbgText(arg)));
+            xsldbgGenericErrorFunc(i18n("Error: Breakpoint at template \"%1\" does not exist.\n", xsldbgText(arg)));
     }
 
     if (!result)
@@ -877,16 +766,7 @@ xslDbgShellEnable(xmlChar * arg, int enableType)
 }
 
 
-/**
- * xslDbgShellPrintBreakPoint:
- * @payload: A valid breakPointPtr
- * @data: Not used
- * @name: Not used
- *
- * Print data given by scan of break points 
-*/
-void
-xslDbgShellPrintBreakPoint(void *payload, void *data,
+void xslDbgShellPrintBreakPoint(void *payload, void *data,
                            xmlChar * name)
 {
     Q_UNUSED(data);
@@ -949,11 +829,11 @@ static int validateBreakPoint(breakPointPtr breakPtr, breakPointPtr copy)
 		    breakPointCounter = lastCounter; /* compensate for breakPointAdd which always 
 							increments the breakPoint counter */
 		    result = 1;
-		    xsldbgGenericErrorFunc(i18n("Information: Breakpoint validation has caused breakpoint %1 to be re-created.\n").arg(breakPtr->id));
+		    xsldbgGenericErrorFunc(i18n("Information: Breakpoint validation has caused breakpoint %1 to be re-created.\n", breakPtr->id));
 		}
 	    }
 	    if (!result){
-		xsldbgGenericErrorFunc(i18n("Warning: Validation of breakpoint %1 failed.\n").arg(copy->id));
+		xsldbgGenericErrorFunc(i18n("Warning: Validation of breakpoint %1 failed.\n", copy->id));
 	    }
 	}
     }
@@ -961,9 +841,7 @@ static int validateBreakPoint(breakPointPtr breakPtr, breakPointPtr copy)
     return result;
 }
 
-/* Validiate a breakpoint at a given URL and line number  
-   breakPtr, copy and ctx must be valid
- */
+
 static int validateTemplateBreakPoint(breakPointPtr breakPtr, breakPointPtr copy, xsltTransformContextPtr ctxt)
 {
     int result = 0;
@@ -992,7 +870,7 @@ static int validateTemplateBreakPoint(breakPointPtr breakPtr, breakPointPtr copy
     }
     xmlFree(copy->templateName);
     if (!result){
-	xsldbgGenericErrorFunc(i18n("Warning: Validation of breakpoint %1 failed.\n").arg(copy->id));
+	xsldbgGenericErrorFunc(i18n("Warning: Validation of breakpoint %1 failed.\n", copy->id));
     }
     return result;
 }
